@@ -23,8 +23,8 @@ class EditForm(forms.ModelForm):
         model = Node
         fields = ('name', 'host', 'port', 'secret', 'version', 'group',)
         widgets = {
-            'host': forms.TextInput(attrs={'placeholder': 'Host name or IP address'}),
-            'port': forms.TextInput(attrs={'placeholder': 'Port number'}),
+            'host': forms.TextInput(attrs={'placeholder': _('Host name or IP address')}),
+            'port': forms.TextInput(attrs={'placeholder': _('Port number')}),
         }
 
 
