@@ -13,12 +13,11 @@ from string import letters
 from django import forms
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
-from django.contrib.auth.models import User
 from django.db import transaction
 from django.forms.widgets import CheckboxSelectMultiple
 from django.contrib.auth.models import Permission
-from varnish_bans_manager.core.models import UserProfile
-from varnish_bans_manager.core.models.user_profile import PERMISSIONS
+from varnish_bans_manager.core.models import User, UserProfile
+from varnish_bans_manager.core.models.user import PERMISSIONS
 from varnish_bans_manager.core.helpers.paginator import Paginator
 from varnish_bans_manager.core.forms.base import FallbackIntegerField, FallbackCharField, FallbackBooleanField, SortDirectionField, IntegerListField
 
@@ -131,7 +130,8 @@ class EditForm(object):
                 "This e-mail address is already in use."),
         }
 
-        def __init__(self, permissions=[], *args, **kwargs):
+        def __init__(self, permissions=None, *args, **kwargs):
+            permissions = permissions if permissions is not None else []
             super(EditForm.UserForm, self).__init__(*args, **kwargs)
             self.fields['email'].required = True
             self.fields['permissions'] = forms.MultipleChoiceField(
@@ -197,11 +197,13 @@ class AddForm(EditForm):
 
     def __init__(self, user, data=None, files=None):
         self.creator = user
-        super(AddForm, self).__init__(user=User(), permissions=[], profile=UserProfile(), data=data, files=files)
+        super(AddForm, self).__init__(
+            user=User(), permissions=[], profile=UserProfile(), data=data,
+            files=files)
 
     def save(self):
         user = self.user.save()
-        profile = user.get_profile()
+        profile = user.profile
         profile.creator = self.creator
         profile.photo = self.profile.cleaned_data.get('photo')
         profile.save()
@@ -215,8 +217,10 @@ class UpdateForm(EditForm):
                 raise forms.ValidationError(self.error_messages['duplicated_email'])
             return email
 
-        def __init__(self, permissions=[], *args, **kwargs):
-            super(UpdateForm.UserForm, self).__init__(permissions=permissions, *args, **kwargs)
+        def __init__(self, permissions=None, *args, **kwargs):
+            permissions = permissions if permissions is not None else []
+            super(UpdateForm.UserForm, self).__init__(
+                permissions=permissions, *args, **kwargs)
             self.fields['password1'].required = False
             self.fields['password2'].required = False
 
@@ -243,7 +247,9 @@ class UpdateForm(EditForm):
 
     def __init__(self, instance, data=None, files=None):
         permissions = instance.user_permissions.all().values_list('codename', flat=True)
-        super(UpdateForm, self).__init__(user=instance, permissions=permissions, profile=instance.get_profile(), data=data, files=files)
+        super(UpdateForm, self).__init__(
+            user=instance, permissions=permissions, profile=instance.profile,
+            data=data, files=files)
 
     def save(self):
         # Save in a transaction as concurrent edition of the profile may raise an exception.
